"""Test global context."""

import re

import pytest
from sphinx.application import Sphinx


@pytest.mark.sphinx("html", confoverrides={"extensions": ["sphinx_docsearch"]})
def test_global_context(app: Sphinx) -> None:
    """It adds all the DocSearch configuration to global context."""
    app.build()

    pattern = re.compile(r"^docsearch_")
    docsearch_config = filter(pattern.search, app.builder.globalcontext)
    assert len(list(docsearch_config)) == 10

    assert "docsearch_app_id" in app.builder.globalcontext
    assert "docsearch_api_key" in app.builder.globalcontext
    assert "docsearch_askai" in app.builder.globalcontext
    assert "docsearch_index_name" in app.builder.globalcontext
    assert "docsearch_initial_query" in app.builder.globalcontext
    assert "docsearch_container" in app.builder.globalcontext
    assert "docsearch_placeholder" in app.builder.globalcontext
    assert "docsearch_search_parameters" in app.builder.globalcontext
    assert "docsearch_max_results_per_group" in app.builder.globalcontext
    assert "docsearch_missing_results_url" in app.builder.globalcontext
    assert app.builder.globalcontext["docsearch_container"] == "#docsearch"



"""Test configuration checks."""

import os
import re
from pathlib import Path

import pytest
from sphinx.application import Sphinx

from .utils import read_as_html


@pytest.mark.sphinx("html", confoverrides={"extensions": ["sphinx_docsearch"]})
def test_docsearch_assets(app: Sphinx) -> None:
    """It adds all the DocSearch assets to the HTML output."""
    app.build()
    assert os.path.exists(Path(app.outdir) / "_static" / "docsearch.css")
    assert os.path.exists(Path(app.outdir) / "_static" / "docsearch.js")
    assert os.path.exists(Path(app.outdir) / "_static" / "docsearch_config.js")
    test_file = read_as_html(Path(app.outdir) / "index.html")

    css = test_file.select("link[rel='stylesheet']")
    css = [x["href"] for x in css]
    assert any(re.search(r"_static/docsearch.css", str(i)) for i in css)
    assert any(
        re.search(r"_static/alabaster-docsearch-custom.css", str(i)) for i in css
    )

    scripts = test_file.select("script")
    scripts = [x["src"] for x in scripts]
    assert any(re.search(r"_static/docsearch.js", str(i)) for i in scripts)
    assert any(re.search(r"_static/docsearch_config.js", str(i)) for i in scripts)


@pytest.mark.sphinx(
    "html", confoverrides={"extensions": ["sphinx_docsearch"], "html_theme": "furo"}
)
def test_custom_furo_assets(app: Sphinx) -> None:
    """It adds the custom CSS for the furo theme."""
    app.build()
    assert os.path.exists(Path(app.outdir) / "_static" / "furo-docsearch-custom.css")
    test_file = read_as_html(Path(app.outdir) / "index.html")

    css = test_file.select("link[rel='stylesheet']")
    css = [x["href"] for x in css]
    assert any(re.search(r"_static/furo-docsearch-custom.css", str(i)) for i in css)


@pytest.mark.sphinx(
    "html",
    confoverrides={
        "extensions": ["sphinx_docsearch"],
        "html_theme": "sphinx_rtd_theme",
    },
)
def test_custom_rtd_assets(app: Sphinx) -> None:
    """It adds the custom CSS for the read the docs theme."""
    app.build()
    assert os.path.exists(Path(app.outdir) / "_static" / "rtd-docsearch-custom.css")
    test_file = read_as_html(Path(app.outdir) / "index.html")

    css = test_file.select("link[rel='stylesheet']")
    css = [x["href"] for x in css]
    assert any(re.search("_static/rtd-docsearch-custom.css", str(i)) for i in css)


@pytest.mark.sphinx(
    "html",
    confoverrides={
        "extensions": ["sphinx_docsearch"],
        "html_theme": "pydata_sphinx_theme",
    },
)
def test_custom_pydata_assets(app: Sphinx) -> None:
    """It adds the custom CSS for the read the docs theme."""
    app.build()
    assert os.path.exists(Path(app.outdir) / "_static" / "pydata-docsearch-custom.css")
    test_file = read_as_html(Path(app.outdir) / "index.html")

    css = test_file.select("link[rel='stylesheet']")
    css = [x["href"] for x in css]
    assert any(re.search("_static/pydata-docsearch-custom.css", str(i)) for i in css)
